==> woocommerce-bookings_2.2.9%28www.persianscript.ir%29.zip: woocommerce-bookings/lib/packages/google/apiclient-services/src/Calendar/Resource/Channels.php <==
<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 * Modified by woocommerce on 07-August-2025 using Strauss.
 * @see https://github.com/BrianHenryIE/strauss
 */

namespace Automattic\WooCommerce\Bookings\Vendor\Google\Service\Calendar\Resource;

use Automattic\WooCommerce\Bookings\Vendor\Google\Service\Calendar\Channel;

/**
 * The "channels" collection of methods.
 * Typical usage is:
 *  <code>
 *   $calendarService = new \Automattic\WooCommerce\Bookings\Vendor\Google\Service\Calendar(...);
 *   $channels = $calendarService->channels;
 *  </code>
 */
class Channels extends \Automattic\WooCommerce\Bookings\Vendor\Google\Service\Resource
{
  /**
   * Stop watching resources through this channel (channels.stop)
   *
   * @param Channel $postBody
   * @param array $optParams Optional parameters.
   */
  public function stop(Channel $postBody, $optParams = [])
  {
    $params = ['postBody' => $postBody];
    $params = array_merge($params, $optParams);
    return $this->call('stop', [$params]);
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(Channels::class, 'Google_Service_Calendar_Resource_Channels');

==> woocommerce-bookings-3.1.0%28www.persianscript.ir%29.zip: woocommerce-bookings/lib/packages/google/apiclient-services/src/Calendar/Resource/Channels.php <==
<?php
/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 * Modified by woocommerce on 28-January-2026 using Strauss.
 * @see https://github.com/BrianHenryIE/strauss
 */

namespace Automattic\WooCommerce\Bookings\Vendor\Google\Service\Calendar\Resource;

use Automattic\WooCommerce\Bookings\Vendor\Google\Service\Calendar\Channel;

/**
 * The "channels" collection of methods.
 * Typical usage is:
 *  <code>
 *   $calendarService = new \Automattic\WooCommerce\Bookings\Vendor\Google\Service\Calendar(...);
 *   $channels = $calendarService->channels;
 *  </code>
 */
class Channels extends \Automattic\WooCommerce\Bookings\Vendor\Google\Service\Resource
{
  /**
   * Stop watching resources through this channel (channels.stop)
   *
   * @param Channel $postBody
   * @param array $optParams Optional parameters.
   */
  public function stop(Channel $postBody, $optParams = [])
  {
    $params = ['postBody' => $postBody];
    $params = array_merge($params, $optParams);
    return $this->call('stop', [$params]);
  }
}

// Adding a class alias for backwards compatibility with the previous class name.
class_alias(Channels::class, 'Google_Service_Calendar_Resource_Channels');
